package com.adzel.velocitybroadcast;

import java.util.List;

import com.adzel.velocitybroadcast.util.DatabaseManager;
import com.velocitypowered.api.command.CommandSource;
import com.velocitypowered.api.command.SimpleCommand;
import com.velocitypowered.api.proxy.Player;

import net.kyori.adventure.text.Component;
import net.kyori.adventure.text.minimessage.MiniMessage;

public class BroadcastCommand implements SimpleCommand {

    private final VelocityBroadcast plugin;
    private final DatabaseManager databaseManager;
    private final MiniMessage mm = MiniMessage.miniMessage();

    public BroadcastCommand(VelocityBroadcast plugin) {
        this.plugin = plugin;
        this.databaseManager = plugin.getDatabaseManager();
    }

    @Override
    public void execute(Invocation invocation) {
        CommandSource source = invocation.source();
        List<String> args = List.of(invocation.arguments());

        if (!source.hasPermission("vb.broadcast")) {
            source.sendMessage(mm.deserialize("<red>You don't have permission to use this command.</red>"));
            return;
        }

        if (args.isEmpty()) {
            source.sendMessage(mm.deserialize("<red>Usage: /vb <message></red>"));
            return;
        }

        String messageRaw = String.join(" ", args);
        String prefix = plugin.getConfigHandler().getPrefix();
        String fullMessage = prefix + messageRaw;

        Component broadcast = mm.deserialize(fullMessage);
        plugin.getServer().getAllPlayers().forEach(player -> player.sendMessage(broadcast));

        if (plugin.getConfigHandler().isDebugEnabled()) {
            plugin.getLogger().info("[Broadcast] Sent: " + fullMessage);
        }

        // ✅ Log to the database with proper sender
        String sender = (source instanceof Player player) ? player.getUsername() : "Console";
        String sourceServer = plugin.getServer().getBoundAddress().toString();
        databaseManager.logBroadcast(sender, messageRaw, sourceServer);

        // Optional feedback to source
        source.sendMessage(mm.deserialize("<green>Broadcast sent.</green>"));
    }
}
